Method for extracting model fitted values from a fitted GLMM (abund).
# S3 method for abund
fitted(object, ...)A three-dimensional numeric array of fitted values for use in Goodness of Fit assessments. Array dimensions correspond to MCMC samples, sites, and replicates
object of class abund.
currently no additional arguments
A method to the generic fitted function to extract fitted values for fitted model objects of class abund.