Method for extracting model fitted values and cell-specific detection probabilities from a multi-species hierarchical distance sampling (msDS) model.
# S3 method for msDS
fitted(object, ...)A list comprised of:
A four-dimensional numeric array of fitted values for use in Goodness of Fit assessments. Array dimensions correspond to MCMC samples, species, sites, and distance bin.
A four-dimensional numeric array of cell-specific detection probability values. Values correspond to the probability of detecting an individual within a given distance band at a given location. Array dimensions correspond to MCMC samples, species, sites, and distance band.
object of class msDS.
currently no additional arguments
A method to the generic fitted function to extract fitted values and detection probabilities for fitted model objects of class msDS.