Methods for extracting information from fitted multi-species hierarchical distance sampling (msDS) model.
# S3 method for msDS
summary(object, level = 'both', quantiles = c(0.025, 0.5, 0.975),
digits = max(3L, getOption("digits") - 3L), ...)
# S3 method for msDS
print(x, ...)
# S3 method for msDS
plot(x, param, density = TRUE, ...)No return value, called to display summary information of a msDS object.
object of class msDS.
a quoted keyword that indicates the level to summarize the
model results. Valid key words are: "community",
"species", or "both".
for summary, posterior distribution quantiles to compute.
for summary, number of digits to report.
parameter name for which to generate a traceplot. Valid names are
"beta", "beta.star", "sigma.sq.mu", "beta.comm", "tau.sq.beta",
"alpha", "alpha.star", "sigma.sq.p", "alpha.comm", "tau.sq.alpha".
logical value indicating whether to also generate a density plot for each parameter in addition to the MCMC traceplot.
currently no additional arguments
A set of standard extractor functions for fitted model objects of
class msDS, including methods to the generic functions print, summary, and plot.